@@ -53,13 +53,14 @@ NULL
 #' 1200-1211.
 #'
 #' @examples
-#' bake_par <- make_bakepar()
-#' constants <- make_constants(use_tealeaves = FALSE)
-#' leaf_par <- make_leafpar(
-#'   replace = list(T_leaf = set_units(293.15, "K")),
+#' bake_par = make_bakepar()
+#' constants = make_constants(use_tealeaves = FALSE)
+#' enviro_par = make_enviropar(use_tealeaves = FALSE)
+#' leaf_par = make_leafpar(
+#'   replace = list(T_leaf = set_units(293.15, K)),
 #'   use_tealeaves = FALSE
 #' )
-#' baked_leafpar <- bake(leaf_par, bake_par, constants)
+#' baked_leafpar = bake(leaf_par, enviro_par, bake_par, constants)
 #'
 #' baked_leafpar$V_cmax25
 #' baked_leafpar$V_cmax
@@ -67,82 +68,95 @@ NULL
 #'
 #' @export
 
-bake <- function(leaf_par, bake_par, constants, assert_units = TRUE) {
+bake = function(
+    leaf_par, 
+    enviro_par, 
+    bake_par, 
+    constants, 
+    assert_units = TRUE
+  ) {
+  
+  # Assert units before baking ----
   if (assert_units) {
     leaf_par %<>% leaf_par(use_tealeaves = FALSE)
+    enviro_par %<>% enviro_par(use_tealeaves = FALSE)
     bake_par %<>% bake_par()
     constants %<>% constants(use_tealeaves = FALSE)
   }
 
-  pars <- c(leaf_par, bake_par, constants) %>%
+  # Remove units prior to baking ----
+  pars = c(leaf_par, enviro_par, bake_par, constants) |>
     purrr::map_if(~ inherits(.x, "units"), drop_units)
-  T_ref <- 298.15
-
-  leaf_par$g_mc <- temp_resp2(pars$g_mc25, pars$Ds_gmc, pars$Ea_gmc,
-    pars$Ed_gmc, pars$R, pars$T_leaf, T_ref,
-    unitless = TRUE
-  )
-  leaf_par$gamma_star <- temp_resp1(pars$gamma_star25, pars$Ea_gammastar,
+  T_ref = 298.15
+  
+  # Calculate parameters at T_leaf based on temperature response function ----
+  # Assumes that g_liqc has same temperature response function as g_mc
+  if (length(pars$g_liqc25) != 0) {
+    leaf_par$g_liqc = temp_resp2(
+      pars$g_liqc25, pars$Ds_gmc, pars$Ea_gmc, pars$Ed_gmc, pars$R, pars$T_leaf, 
+      T_ref, unitless = TRUE
+    )
+  }
+  
+  if (length(leaf_par$delta_ias_lower) != 0 & length(leaf_par$delta_ias_upper) != 0) {
+    D_c = tealeaves:::.get_Dx(pars$D_c0, pars$T_leaf, pars$eT, pars$P,
+                              unitless = TRUE)
+    leaf_par$g_iasc_lower = 1e9 * D_c / pars$delta_ias_lower * 
+      pars$P / (pars$R * pars$T_leaf)
+    leaf_par$g_iasc_upper = 1e9 * D_c / pars$delta_ias_upper * 
+      pars$P / (pars$R * pars$T_leaf)
+  }
+  
+  if (length(pars$g_mc25) != 0) {
+    leaf_par$g_mc = temp_resp2(
+      pars$g_mc25, pars$Ds_gmc, pars$Ea_gmc, pars$Ed_gmc, pars$R, pars$T_leaf, 
+      T_ref, unitless = TRUE
+    )
+  }
+  
+  leaf_par$gamma_star = temp_resp1(pars$gamma_star25, pars$Ea_gammastar,
     pars$R, pars$T_leaf, T_ref,
     unitless = TRUE
   )
-  leaf_par$J_max <- temp_resp2(pars$J_max25, pars$Ds_Jmax, pars$Ea_Jmax,
+  leaf_par$J_max = temp_resp2(pars$J_max25, pars$Ds_Jmax, pars$Ea_Jmax,
     pars$Ed_Jmax, pars$R, pars$T_leaf, T_ref,
     unitless = TRUE
   )
-  leaf_par$K_C <- temp_resp1(pars$K_C25, pars$Ea_KC, pars$R, pars$T_leaf,
+  leaf_par$K_C = temp_resp1(pars$K_C25, pars$Ea_KC, pars$R, pars$T_leaf,
     T_ref,
     unitless = TRUE
   )
-  leaf_par$K_O <- temp_resp1(pars$K_O25, pars$Ea_KO, pars$R, pars$T_leaf,
+  leaf_par$K_O = temp_resp1(pars$K_O25, pars$Ea_KO, pars$R, pars$T_leaf,
     T_ref,
     unitless = TRUE
   )
-  leaf_par$R_d <- temp_resp1(pars$R_d25, pars$Ea_Rd, pars$R, pars$T_leaf,
+  leaf_par$R_d = temp_resp1(pars$R_d25, pars$Ea_Rd, pars$R, pars$T_leaf,
     T_ref,
     unitless = TRUE
   )
-  leaf_par$V_cmax <- temp_resp1(pars$V_cmax25, pars$Ea_Vcmax, pars$R,
+  leaf_par$V_cmax = temp_resp1(pars$V_cmax25, pars$Ea_Vcmax, pars$R,
     pars$T_leaf, T_ref,
     unitless = TRUE
   )
-  leaf_par$V_tpu <- temp_resp1(pars$V_tpu25, pars$Ea_Vtpu, pars$R, pars$T_leaf,
+  leaf_par$V_tpu = temp_resp1(pars$V_tpu25, pars$Ea_Vtpu, pars$R, pars$T_leaf,
     T_ref,
     unitless = TRUE
   )
+  
   # Set units ----
-  if (assert_units) {
-    leaf_par$g_mc %<>% set_units(umol / m^2 / s / Pa)
-    leaf_par$gamma_star %<>% set_units(Pa)
-    leaf_par$J_max %<>% set_units(umol / (m^2 * s))
-    leaf_par$K_C %<>% set_units(Pa)
-    leaf_par$K_O %<>% set_units(kPa)
-    leaf_par$R_d %<>% set_units(umol / (m^2 * s))
-    leaf_par$V_cmax %<>% set_units(umol / (m^2 * s))
-    leaf_par$V_tpu %<>% set_units(umol / (m^2 * s))
-  }
+  leaf_par = set_parameter_units(leaf_par, .data$R %in% names(leaf_par))
 
-  # Check values ----
+  # Assert bounds on values ----
+  # If !assert_units, no assertion is performed
   if (assert_units) {
-    stopifnot(leaf_par$g_mc >= set_units(0, umol / m^2 / s / Pa))
-    stopifnot(leaf_par$gamma_star >= set_units(0, Pa))
-    stopifnot(leaf_par$J_max >= set_units(0, umol / (m^2 * s)))
-    stopifnot(leaf_par$K_C >= set_units(0, Pa))
-    stopifnot(leaf_par$K_O >= set_units(0, kPa))
-    stopifnot(leaf_par$R_d >= set_units(0, umol / (m^2 * s)))
-    stopifnot(leaf_par$V_cmax >= set_units(0, umol / (m^2 * s)))
-    stopifnot(leaf_par$V_tpu >= set_units(0, umol / (m^2 * s)))
-  } else {
-    stopifnot(leaf_par$g_mc >= 0)
-    stopifnot(leaf_par$gamma_star >= 0)
-    stopifnot(leaf_par$J_max >= 0)
-    stopifnot(leaf_par$K_C >= 0)
-    stopifnot(leaf_par$K_O >= 0)
-    stopifnot(leaf_par$R_d >= 0)
-    stopifnot(leaf_par$V_cmax >= 0)
-    stopifnot(leaf_par$V_tpu >= 0)
+    leaf_par |>
+      assert_parameter_bounds(
+        .data$type == "leaf", 
+        .data$temperature_response,
+        !.data$tealeaves
+      )
   }
-
+  
   leaf_par %<>% structure(class = c("baked", "leaf_par", "list"))
 
   leaf_par
@@ -163,11 +177,11 @@ bake <- function(leaf_par, bake_par, constants, assert_units = TRUE) {
 #'
 #' @export
 
-temp_resp1 <- function(par25, E_a, R, T_leaf, T_ref, unitless) {
+temp_resp1 = function(par25, E_a, R, T_leaf, T_ref, unitless) {
   if (unitless) {
     T_leaf %<>% magrittr::subtract(273.15)
   } else {
-    pars_unit <- units(par25)
+    pars_unit = units(par25)
     par25 %<>% drop_units()
 
     E_a %<>% set_units(J / mol) %>% drop_units()
@@ -176,10 +190,10 @@ temp_resp1 <- function(par25, E_a, R, T_leaf, T_ref, unitless) {
     T_ref %<>% set_units(K) %>% drop_units()
   }
 
-  a1 <- exp(E_a / (R * T_ref) * ((T_leaf - 25) / (T_leaf + 273.15)))
+  a1 = exp(E_a / (R * T_ref) * ((T_leaf - 25) / (T_leaf + 273.15)))
 
-  ret <- par25 * a1
-  if (!unitless) units(ret) <- pars_unit
+  ret = par25 * a1
+  if (!unitless) units(ret) = pars_unit
   ret
 }
 
@@ -195,13 +209,13 @@ temp_resp1 <- function(par25, E_a, R, T_leaf, T_ref, unitless) {
 #'
 #' @export
 
-temp_resp2 <- function(par25, D_s, E_a, E_d, R, T_leaf, T_ref, unitless) {
-  a1 <- temp_resp1(par25, E_a, R, T_leaf, T_ref, unitless)
+temp_resp2 = function(par25, D_s, E_a, E_d, R, T_leaf, T_ref, unitless) {
+  a1 = temp_resp1(par25, E_a, R, T_leaf, T_ref, unitless)
 
   if (unitless) {
     T_leaf %<>% magrittr::subtract(273.15)
   } else {
-    pars_unit <- units(par25)
+    pars_unit = units(par25)
     par25 %<>% drop_units()
     a1 %<>% drop_units()
 
@@ -213,10 +227,10 @@ temp_resp2 <- function(par25, D_s, E_a, E_d, R, T_leaf, T_ref, unitless) {
     T_ref %<>% set_units(K) %>% drop_units()
   }
 
-  a2 <- (1 + exp((D_s / R - E_d / (R * T_ref)))) /
+  a2 = (1 + exp((D_s / R - E_d / (R * T_ref)))) /
     (1 + exp((D_s / R) - (E_d / (R * (T_leaf + 273.15)))))
 
-  ret <- a1 * a2
-  if (!unitless) units(ret) <- pars_unit
+  ret = a1 * a2
+  if (!unitless) units(ret) = pars_unit
   ret
 }
